@@ -1,17 +1,14 @@
 """Testing aggregation of ensembles."""
 
 import os
+import logging
+
 import pandas as pd
 import pytest
 
-from fmu.ensemble import etc
 from fmu.ensemble import ScratchEnsemble
 
-fmux = etc.Interaction()
-logger = fmux.basiclogger(__name__, level="WARNING")
-
-if not fmux.testsetup():
-    raise SystemExit()
+logger = logging.getLogger(__name__)
 
 
 def test_ensemble_aggregations(tmpdir):
